==> wiki3_4_3.zip: wiki3_4_3/plugin/recent/Recent.pm <==
############################################################
# 
# Ƕṹ줿ڡɽޤ
# ɽǤޤ
# <pre>
# {{recent 5}}
# </pre>
# Ĥɽ뤳ȤǤޤ
# <pre>
# {{recent 5,v}}
# </pre>
# դȤ˰ɽˤrecentdaysץ饰Ѥޤ
# 
############################################################
package plugin::recent::Recent;
#use strict;
use plugin::recent::RecentCache;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ȥե
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $max  = shift;
	my $way  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $cachefile = $wiki->config('log_dir')."/recent.cache";
	if (-e $cachefile) {
	} else {
		&plugin::recent::RecentCache::update_cache($wiki);
	}

	my $buf = &Util::load_config_text(undef, $cachefile);
	my @lines = split(/\n/, $buf);
	
	if($way eq ""){
		$way = "H";
	}
	
	if($max eq "V" || $max eq "v"){
		$way = "V";
		$max = "";
	} elsif($max eq "H" || $max eq "h"){
		$way = "H";
		$max = "";
	}
	
	my $content = "";
	my $count = 0;
	
	if($way ne "H" && $way ne "h"){
		$content = "<ul>\n";
	}
	
	foreach my $line (@lines){
	    my @keys = split(/\t/, $line);
	    my $page = $keys[0];

		if($max ne "" && $count==$max){
			last;
		}
		if($way eq "H" || $way eq "h"){
			if($count!=0){
				$content = $content." / ";
			}
		} else {
			$content = $content."<li>";
		}
		$content = $content.
		    "<a href=\"".$wiki->config('script_name')."?page=".Util::url_encode($page)."\">".$cgi->escapeHTML($page)."</a>";
		$count++;
		if($way ne "H" && $way ne "h"){
			$content .= "</li>\n";
		}
	}
	
	if($way ne "H" && $way ne "h"){
		$content .= "</ul>\n";
	}
	
	return $content;
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/recent/Recent.pm <==
############################################################
# 
# Ƕṹ줿ڡɽޤ
# ɽǤޤ
# <pre>
# {{recent 5}}
# </pre>
# Ĥɽ뤳ȤǤޤ
# <pre>
# {{recent 5,v}}
# </pre>
# դȤ˰ɽˤrecentdaysץ饰Ѥޤ
# 
############################################################
package plugin::recent::Recent;
#use strict;
use plugin::recent::RecentCache;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ѥ饰ե᥽å
#===========================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $max    = shift;
	my $way    = shift;
	my $cgi    = $wiki->get_CGI;
	
	my $cachefile = $wiki->config('log_dir')."/recent.cache";
	if (-e $cachefile) {
	} else {
		&plugin::recent::RecentCache::update_cache($wiki);
	}

	my $buf = &Util::load_config_text(undef, $cachefile);
	my @lines = split(/\n/, $buf);
	
	if($way eq ""){
		$way = "H";
	}
	
	if($max eq "V" || $max eq "v"){
		$way = "V";
		$max = "";
	} elsif($max eq "H" || $max eq "h"){
		$way = "H";
		$max = "";
	}
	
	my $content = "";
	my $count = 0;
	
	foreach my $line (@lines){
		my @keys = split(/\t/, $line);
		my $page = $keys[0];
		if($max ne "" && $count==$max){
			last;
		}
		if($way eq "H" || $way eq "h"){
			if($count!=0){
				$content = $content." / ";
			}
		} else {
			$content = $content."*";
		}
		$content = $content."[[$page]]";
		$count++;
		if($way ne "H" && $way ne "h"){
			$content .= "\n";
		}
	}
	
	return $content;
}

1;
